#[repr(transparent)]pub struct PhantomContravariant<T>(PhantomData<fn(T)>)
where
T: ?Sized;🔬This is a nightly-only experimental API. (
phantom_variance_markers #135806)Expand description
Zero-sized type used to mark a type parameter as contravariant.
Types passed as arguments to a function are contravariant. If the type is also part of the return value from a function then it is invariant. See the reference for more information.
Note: If T is otherwise covariant or invariant, the resulting type is invariant.
Layout
For all T, the following are guaranteed:
size_of::<PhantomContravariant<T>>() == 0align_of::<PhantomContravariant<T>>() == 1
Tuple Fields
0: PhantomData<fn(T)>🔬This is a nightly-only experimental API. (
phantom_variance_markers #135806)Implementations